@@ -19,21 +19,23 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 from __future__ import annotations
 
+from collections.abc import Awaitable
 from inspect import iscoroutinefunction
 from types import FunctionType
-from typing import TYPE_CHECKING, Awaitable, Generic, TypeVar, cast, overload
+from typing import TYPE_CHECKING, Generic, TypeVar, cast, overload
 from weakref import ref as weak_ref
 
 from .dbus_common_elements import (
-    DbusBindedAsync,
+    DbusBoundAsync,
+    DbusMemberAsync,
     DbusPropertyCommon,
     DbusPropertyOverride,
     DbusRemoteObjectMeta,
-    DbusSomethingAsync,
 )
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Generator, Optional, Type, Union
+    from collections.abc import Callable, Generator
+    from typing import Any, Optional, Union
 
     from .dbus_proxy_async_interface_base import DbusInterfaceBaseAsync
     from .sd_bus_internals import SdBusMessage
@@ -42,7 +44,7 @@ if TYPE_CHECKING:
 T = TypeVar('T')
 
 
-class DbusPropertyAsync(DbusSomethingAsync, DbusPropertyCommon, Generic[T]):
+class DbusPropertyAsync(DbusMemberAsync, DbusPropertyCommon, Generic[T]):
     def __init__(
             self,
             property_name: Optional[str],
@@ -75,7 +77,7 @@ class DbusPropertyAsync(DbusSomethingAsync, DbusPropertyCommon, Generic[T]):
     def __get__(
         self,
         obj: None,
-        obj_class: Type[DbusInterfaceBaseAsync],
+        obj_class: type[DbusInterfaceBaseAsync],
     ) -> DbusPropertyAsync[T]:
         ...
 
@@ -83,21 +85,21 @@ class DbusPropertyAsync(DbusSomethingAsync, DbusPropertyCommon, Generic[T]):
     def __get__(
         self,
         obj: DbusInterfaceBaseAsync,
-        obj_class: Type[DbusInterfaceBaseAsync],
-    ) -> DbusPropertyAsyncBaseBind[T]:
+        obj_class: type[DbusInterfaceBaseAsync],
+    ) -> DbusBoundPropertyAsyncBase[T]:
         ...
 
     def __get__(
         self,
         obj: Optional[DbusInterfaceBaseAsync],
-        obj_class: Optional[Type[DbusInterfaceBaseAsync]] = None,
-    ) -> Union[DbusPropertyAsyncBaseBind[T], DbusPropertyAsync[T]]:
+        obj_class: Optional[type[DbusInterfaceBaseAsync]] = None,
+    ) -> Union[DbusBoundPropertyAsyncBase[T], DbusPropertyAsync[T]]:
         if obj is not None:
             dbus_meta = obj._dbus
             if isinstance(dbus_meta, DbusRemoteObjectMeta):
-                return DbusPropertyAsyncProxyBind(self, dbus_meta)
+                return DbusProxyPropertyAsync(self, dbus_meta)
             else:
-                return DbusPropertyAsyncLocalBind(self, obj)
+                return DbusLocalPropertyAsync(self, obj)
         else:
             return self
 
@@ -126,7 +128,7 @@ class DbusPropertyAsync(DbusSomethingAsync, DbusPropertyCommon, Generic[T]):
         self.property_setter_is_public = False
 
 
-class DbusPropertyAsyncBaseBind(DbusBindedAsync, Awaitable[T]):
+class DbusBoundPropertyAsyncBase(DbusBoundAsync, Awaitable[T]):
     def __await__(self) -> Generator[Any, None, T]:
         return self.get_async().__await__()
 
@@ -137,7 +139,7 @@ class DbusPropertyAsyncBaseBind(DbusBindedAsync, Awaitable[T]):
         raise NotImplementedError
 
 
-class DbusPropertyAsyncProxyBind(DbusPropertyAsyncBaseBind[T]):
+class DbusProxyPropertyAsync(DbusBoundPropertyAsyncBase[T]):
     def __init__(
         self,
         dbus_property: DbusPropertyAsync[T],
@@ -179,7 +181,7 @@ class DbusPropertyAsyncProxyBind(DbusPropertyAsyncBaseBind[T]):
         await bus.call_async(new_set_message)
 
 
-class DbusPropertyAsyncLocalBind(DbusPropertyAsyncBaseBind[T]):
+class DbusLocalPropertyAsync(DbusBoundPropertyAsyncBase[T]):
     def __init__(
         self,
         dbus_property: DbusPropertyAsync[T],
