@@ -20,30 +20,24 @@
 from __future__ import annotations
 
 from asyncio import Queue
+from collections.abc import AsyncIterable, AsyncIterator
 from contextlib import closing
 from types import FunctionType
-from typing import (
-    TYPE_CHECKING,
-    AsyncIterable,
-    AsyncIterator,
-    Generic,
-    TypeVar,
-    cast,
-    overload,
-)
+from typing import TYPE_CHECKING, Generic, TypeVar, cast, overload
 from weakref import WeakSet
 
 from .dbus_common_elements import (
-    DbusBindedAsync,
+    DbusBoundAsync,
     DbusLocalObjectMeta,
+    DbusMemberAsync,
     DbusRemoteObjectMeta,
     DbusSignalCommon,
-    DbusSomethingAsync,
 )
-from .dbus_common_funcs import get_default_bus
+from .default_bus import get_default_bus
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Optional, Sequence, Tuple, Type, Union
+    from collections.abc import Callable, Sequence
+    from typing import Any, Optional, Union
 
     from .dbus_proxy_async_interface_base import DbusInterfaceBaseAsync
     from .sd_bus_internals import SdBus, SdBusMessage, SdBusSlot
@@ -52,7 +46,7 @@ if TYPE_CHECKING:
 T = TypeVar('T')
 
 
-class DbusSignalAsync(DbusSomethingAsync, DbusSignalCommon, Generic[T]):
+class DbusSignalAsync(DbusMemberAsync, DbusSignalCommon, Generic[T]):
 
     def __init__(
         self,
@@ -76,7 +70,7 @@ class DbusSignalAsync(DbusSomethingAsync, DbusSignalCommon, Generic[T]):
     def __get__(
         self,
         obj: None,
-        obj_class: Type[DbusInterfaceBaseAsync],
+        obj_class: type[DbusInterfaceBaseAsync],
     ) -> DbusSignalAsync[T]:
         ...
 
@@ -84,21 +78,21 @@ class DbusSignalAsync(DbusSomethingAsync, DbusSignalCommon, Generic[T]):
     def __get__(
         self,
         obj: DbusInterfaceBaseAsync,
-        obj_class: Type[DbusInterfaceBaseAsync],
-    ) -> DbusSignalAsyncBaseBind[T]:
+        obj_class: type[DbusInterfaceBaseAsync],
+    ) -> DbusBoundSignalAsyncBase[T]:
         ...
 
     def __get__(
         self,
         obj: Optional[DbusInterfaceBaseAsync],
-        obj_class: Optional[Type[DbusInterfaceBaseAsync]] = None,
-    ) -> Union[DbusSignalAsyncBaseBind[T], DbusSignalAsync[T]]:
+        obj_class: Optional[type[DbusInterfaceBaseAsync]] = None,
+    ) -> Union[DbusBoundSignalAsyncBase[T], DbusSignalAsync[T]]:
         if obj is not None:
             dbus_meta = obj._dbus
             if isinstance(dbus_meta, DbusRemoteObjectMeta):
-                return DbusSignalAsyncProxyBind(self, dbus_meta)
+                return DbusProxySignalAsync(self, dbus_meta)
             else:
-                return DbusSignalAsyncLocalBind(self, dbus_meta)
+                return DbusLocalSignalAsync(self, dbus_meta)
         else:
             return self
 
@@ -106,7 +100,7 @@ class DbusSignalAsync(DbusSomethingAsync, DbusSignalCommon, Generic[T]):
         self,
         service_name: str,
         bus: Optional[SdBus] = None,
-    ) -> AsyncIterable[Tuple[str, T]]:
+    ) -> AsyncIterable[tuple[str, T]]:
         if bus is None:
             bus = get_default_bus()
 
@@ -131,7 +125,7 @@ class DbusSignalAsync(DbusSomethingAsync, DbusSignalCommon, Generic[T]):
                 )
 
 
-class DbusSignalAsyncBaseBind(DbusBindedAsync, AsyncIterable[T], Generic[T]):
+class DbusBoundSignalAsyncBase(DbusBoundAsync, AsyncIterable[T], Generic[T]):
     async def catch(self) -> AsyncIterator[T]:
         raise NotImplementedError
         yield cast(T, None)
@@ -142,7 +136,7 @@ class DbusSignalAsyncBaseBind(DbusBindedAsync, AsyncIterable[T], Generic[T]):
             self,
             service_name: Optional[str] = None,
             bus: Optional[SdBus] = None,
-    ) -> AsyncIterable[Tuple[str, T]]:
+    ) -> AsyncIterable[tuple[str, T]]:
         raise NotImplementedError
         yield "", cast(T, None)
 
@@ -150,7 +144,7 @@ class DbusSignalAsyncBaseBind(DbusBindedAsync, AsyncIterable[T], Generic[T]):
         raise NotImplementedError
 
 
-class DbusSignalAsyncProxyBind(DbusSignalAsyncBaseBind[T]):
+class DbusProxySignalAsync(DbusBoundSignalAsyncBase[T]):
     def __init__(
         self,
         dbus_signal: DbusSignalAsync[T],
@@ -193,7 +187,7 @@ class DbusSignalAsyncProxyBind(DbusSignalAsyncBaseBind[T]):
             self,
             service_name: Optional[str] = None,
             bus: Optional[SdBus] = None,
-    ) -> AsyncIterable[Tuple[str, T]]:
+    ) -> AsyncIterable[tuple[str, T]]:
         if bus is None:
             bus = self.proxy_meta.attached_bus
 
@@ -224,7 +218,7 @@ class DbusSignalAsyncProxyBind(DbusSignalAsyncBaseBind[T]):
         raise RuntimeError("Cannot emit signal from D-Bus proxy.")
 
 
-class DbusSignalAsyncLocalBind(DbusSignalAsyncBaseBind[T]):
+class DbusLocalSignalAsync(DbusBoundSignalAsyncBase[T]):
     def __init__(
         self,
         dbus_signal: DbusSignalAsync[T],
@@ -254,7 +248,7 @@ class DbusSignalAsyncLocalBind(DbusSignalAsyncBaseBind[T]):
         self,
         service_name: Optional[str] = None,
         bus: Optional[SdBus] = None,
-    ) -> AsyncIterable[Tuple[str, T]]:
+    ) -> AsyncIterable[tuple[str, T]]:
         raise NotImplementedError("TODO")
         yield
 
