@@ -23,11 +23,12 @@ from inspect import iscoroutinefunction
 from types import FunctionType
 from typing import TYPE_CHECKING, Generic, TypeVar, cast
 
-from .dbus_common_elements import DbusPropertyCommon, DbusSomethingSync
+from .dbus_common_elements import DbusMemberSync, DbusPropertyCommon
 from .dbus_common_funcs import _check_sync_in_async_env
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Optional, Type
+    from collections.abc import Callable
+    from typing import Any, Optional
 
     from .dbus_proxy_sync_interface_base import DbusInterfaceBase
 
@@ -35,7 +36,7 @@ if TYPE_CHECKING:
 T = TypeVar('T')
 
 
-class DbusPropertySync(DbusPropertyCommon, DbusSomethingSync, Generic[T]):
+class DbusPropertySync(DbusPropertyCommon, DbusMemberSync, Generic[T]):
     def __init__(
             self,
             property_name: Optional[str],
@@ -62,7 +63,7 @@ class DbusPropertySync(DbusPropertyCommon, DbusSomethingSync, Generic[T]):
 
     def __get__(self,
                 obj: DbusInterfaceBase,
-                obj_class: Optional[Type[DbusInterfaceBase]] = None,
+                obj_class: Optional[type[DbusInterfaceBase]] = None,
                 ) -> T:
         assert _check_sync_in_async_env(), (
             "Used sync __get__ method in async environment. "
