@@ -112,7 +112,7 @@ class TestConverter(TestCase):
 
         with self.subTest('Parse variant'):
             self.assertEqual(
-                'Tuple[str, Any]', DbusSigToTyping.typing_complete('v')
+                'tuple[str, Any]', DbusSigToTyping.typing_complete('v')
             )
 
         with self.subTest('Splitter test'):
@@ -124,40 +124,40 @@ class TestConverter(TestCase):
         with self.subTest('Parse struct'):
             self.assertEqual(
                 DbusSigToTyping.typing_complete('(sx)'),
-                'Tuple[str, int]',
+                'tuple[str, int]',
             )
 
         with self.subTest('Parse list'):
             self.assertEqual(
                 DbusSigToTyping.typing_complete('a(sx)'),
-                'List[Tuple[str, int]]',
+                'list[tuple[str, int]]',
             )
 
         with self.subTest('Parse dict'):
             self.assertEqual(
                 DbusSigToTyping.typing_complete('a{s(xh)}'),
-                'Dict[str, Tuple[int, int]]',
+                'dict[str, tuple[int, int]]',
             )
 
         with self.subTest('Parse signature'):
             self.assertEqual(
                 DbusSigToTyping.sig_to_typing('a{s(xh)}'),
-                'Dict[str, Tuple[int, int]]',
+                'dict[str, tuple[int, int]]',
             )
 
             self.assertEqual(
                 DbusSigToTyping.sig_to_typing('a{s(xh)}xs'),
-                'Tuple[Dict[str, Tuple[int, int]], int, str]',
+                'tuple[dict[str, tuple[int, int]], int, str]',
             )
 
             self.assertEqual(
                 DbusSigToTyping.sig_to_typing('a{s(xh)}xs'),
-                'Tuple[Dict[str, Tuple[int, int]], int, str]',
+                'tuple[dict[str, tuple[int, int]], int, str]',
             )
 
             self.assertEqual(
                 DbusSigToTyping.sig_to_typing('as'),
-                'List[str]',
+                'list[str]',
             )
 
             self.assertEqual(
@@ -202,10 +202,13 @@ class TestConverter(TestCase):
 
 
 class TestGeneratorAgainstDbus(IsolatedDbusTestCase):
-    def test_generate_from_connection(self) -> None:
+    def setUp(self) -> None:
         if find_spec('jinja2') is None:
             raise SkipTest('Jinja2 not installed')
 
+        super().setUp()
+
+    def test_generate_from_connection(self) -> None:
         with patch("sdbus.__main__.stdout") as stdout_mock:
             generator_main(
                 [
@@ -234,9 +237,6 @@ class TestGeneratorAgainstDbus(IsolatedDbusTestCase):
         )
 
     def test_generate_from_connection_blocking(self) -> None:
-        if find_spec('jinja2') is None:
-            raise SkipTest('Jinja2 not installed')
-
         with patch("sdbus.__main__.stdout") as stdout_mock:
             generator_main(
                 [
@@ -275,6 +275,12 @@ INTERFACE_NO_MEMBERS_XML = """
 
 
 class TestGeneratorSyntaxCompile(TestCase):
+    def setUp(self) -> None:
+        if find_spec('jinja2') is None:
+            raise SkipTest('Jinja2 not installed')
+
+        super().setUp()
+
     def test_syntax_compile_async(self) -> None:
         source_code = generate_py_file(
             interfaces_from_str(test_xml),
